@@ -13,7 +13,7 @@
 
 #include <sendmail.h>
 
-SM_RCSID("@(#)$Id: stats.c,v 8.55 2002/05/21 22:28:52 gshapiro Exp $")
+SM_RCSID("@(#)$Id: stats.c,v 8.56 2002/06/27 22:47:37 gshapiro Exp $")
 
 #include <sendmail/mailstats.h>
 
@@ -47,12 +47,10 @@ markstats(e, to, type)
 {
 	switch (type)
 	{
-#if _FFR_QUARANTINE
 	  case STATS_QUARANTINE:
 		if (e->e_from.q_mailer != NULL)
 			Stat.stat_nq[e->e_from.q_mailer->m_mno]++;
 		break;
-#endif /* _FFR_QUARANTINE */
 
 	  case STATS_REJECT:
 		if (e->e_from.q_mailer != NULL)
@@ -180,9 +178,7 @@ poststats(sfile)
 			stats.stat_bt[i] += Stat.stat_bt[i];
 			stats.stat_nr[i] += Stat.stat_nr[i];
 			stats.stat_nd[i] += Stat.stat_nd[i];
-#if _FFR_QUARANTINE
 			stats.stat_nq[i] += Stat.stat_nq[i];
-#endif /* _FFR_QUARANTINE */
 		}
 		stats.stat_cr += Stat.stat_cr;
 		stats.stat_ct += Stat.stat_ct;
